@@ -9,7 +9,7 @@
 
 #define M_PI 3.14159265358979323846
 
-void
+static void
 clearlooks_rounded_rectangle (cairo_t *cr,
                                  double x, double y, double w, double h,
                                  double radius, uint8 corners)
@@ -45,7 +45,7 @@ clearlooks_rounded_rectangle (cairo_t *cr,
 /* ROTATES ANTI-CLOCKWISE, I THINK :P */
 /* TODO: Do I really need THREE matrices? */
 static void
-rotate_mirror_translate (cairo_t *cr, double radius, double x, double y,
+clearlooks_rotate_mirror_translate (cairo_t *cr, double radius, double x, double y,
                          boolean mirror_horizontally, boolean mirror_vertically)
 {
 	cairo_matrix_t matrix_rotate;
@@ -241,7 +241,6 @@ clearlooks_draw_button (cairo_t *cr,
 	const CairoColor *fill            = &colors->bg[params->state_type];
 	const CairoColor *border_normal   = &colors->shade[7];
 	const CairoColor *border_disabled = &colors->shade[4];
-	const CairoColor *gradient_bottom = &colors->shade[3];
 	
 	/* Set colors and stuff */
 //	if (params->focus && !params->active)
@@ -273,9 +272,9 @@ clearlooks_draw_button (cairo_t *cr,
 		gdouble shade_size = ((100.0/height)*6.0)/100.0; /* 6 pixels */
 		CairoColor top_shade, bottom_shade, middle_shade;
 		
-		shade (fill, &top_shade, 1.6);
-		shade (fill, &bottom_shade, 0.80);
-		shade (fill, &middle_shade, 0.96);
+		ge_shade_color (fill, 1.6, &top_shade);
+		ge_shade_color (fill, 0.80, &bottom_shade);
+		ge_shade_color (fill, 0.96, &middle_shade);
 		
 		pattern	= cairo_pattern_create_linear (0, 0, 0, height);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.0, top_shade.r, top_shade.g, top_shade.b);
@@ -283,8 +282,8 @@ clearlooks_draw_button (cairo_t *cr,
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0-shade_size, middle_shade.r, middle_shade.g, middle_shade.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0, bottom_shade.r, bottom_shade.g, bottom_shade.b);
 /*
-		shade (fill, &top_shade, 1.6); 
-		shade (fill, &bottom_shade, 0.75);
+		ge_shade_color (fill, 1.6, &top_shade); 
+		ge_shade_color (fill, 0.75, &bottom_shade);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.0, top_shade.r, top_shade.g, top_shade.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0, bottom_shade.r, bottom_shade.g, bottom_shade.b);
 */
@@ -623,7 +622,7 @@ clearlooks_draw_slider (cairo_t *cr,
 	if ( params->prelight )
 	{
 		CairoColor highlight;
-		shade (spot, &highlight, 1.5);	
+		ge_shade_color (spot, 1.5, &highlight);	
 		cairo_pattern_add_color_stop_rgb (pattern, 0.0, highlight.r, highlight.g, highlight.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0, spot->r, spot->g, spot->b);
 		cairo_set_source (cr, pattern);
@@ -668,18 +667,14 @@ clearlooks_draw_slider_button (cairo_t *cr,
                                const SliderParameters *slider,
                                int x, int y, int width, int height)
 {
-	const CairoColor *border = &colors->shade[6];
-	CairoColor        top, bottom;
-	cairo_pattern_t *pattern;
-
 	cairo_set_line_width (cr, 1.0);
 	
 	if (slider->horizontal)
-		rotate_mirror_translate (cr, 0, x+0.5, y+0.5, FALSE, FALSE);
+		clearlooks_rotate_mirror_translate (cr, 0, x+0.5, y+0.5, FALSE, FALSE);
 	else
 	{
 		int tmp = height;
-		rotate_mirror_translate (cr, M_PI/2, x+0.5, y+0.5, FALSE, FALSE);
+		clearlooks_rotate_mirror_translate (cr, M_PI/2, x+0.5, y+0.5, FALSE, FALSE);
 		height = width;
 		width = tmp;
 	}
@@ -688,7 +683,8 @@ clearlooks_draw_slider_button (cairo_t *cr,
 	clearlooks_draw_slider (cr, colors, params, 1, 1, width-2, height-2);
 
 	if (width > 24)
-		clearlooks_draw_gripdots (cr, 0, 0, width-2, height-2, 3, 3, 0);}
+		clearlooks_draw_gripdots (cr, 0, 0, width-2, height-2, 3, 3, 0);
+}
 
 void
 clearlooks_draw_progressbar_trough (cairo_t *cr,
@@ -763,9 +759,9 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	if (is_horizontal)
 	{
 		if (progressbar->orientation == CL_ORIENTATION_LEFT_TO_RIGHT)
-			rotate_mirror_translate (cr, 0, x, y, FALSE, FALSE);
+			clearlooks_rotate_mirror_translate (cr, 0, x, y, FALSE, FALSE);
 		else
-			rotate_mirror_translate (cr, 0, x+width, y, TRUE, FALSE);
+			clearlooks_rotate_mirror_translate (cr, 0, x+width, y, TRUE, FALSE);
 	}
 	else
 	{
@@ -774,9 +770,9 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 		width   = tmp;
 
 		if (progressbar->orientation == CL_ORIENTATION_TOP_TO_BOTTOM)
-			rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
+			clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
 		else
-			rotate_mirror_translate (cr, M_PI/2, x, y+width, TRUE, FALSE);
+			clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y+width, TRUE, FALSE);
 	}
 	
 	cairo_save (cr);
@@ -798,7 +794,7 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	cairo_fill_preserve (cr);
 	
 	/* Draw gradient */
-	shade (&colors->spot[1], &shade1, 1.1);
+	ge_shade_color (&colors->spot[1], 1.1, &shade1);
 	pattern = cairo_pattern_create_linear (0, 0, 0, height);
 	cairo_pattern_add_color_stop_rgb (pattern, 0.0, shade1.r, shade1.g, shade1.b);
 	cairo_pattern_add_color_stop_rgb (pattern, 0.6, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b);
@@ -901,7 +897,7 @@ clearlooks_draw_optionmenu (cairo_t *cr,
 	cairo_stroke          (cr);
 }
 
-void
+static void
 clearlooks_draw_menubar0 (cairo_t *cr,
                           const ClearlooksColors *colors,
                           const WidgetParameters *params,
@@ -925,7 +921,7 @@ clearlooks_draw_menubar0 (cairo_t *cr,
 	cairo_stroke (cr);
 }
 
-void
+static void
 clearlooks_draw_menubar2 (cairo_t *cr,
                           const ClearlooksColors *colors,
                           const WidgetParameters *params,
@@ -935,7 +931,7 @@ clearlooks_draw_menubar2 (cairo_t *cr,
 	CairoColor lower;
 	cairo_pattern_t *pattern;
 
-	shade (&colors->bg[0], &lower, 0.95);
+	ge_shade_color (&colors->bg[0], 0.95, &lower);
 	
 	cairo_translate (cr, x, y);
 	cairo_rectangle (cr, 0, 0, width, height);
@@ -962,7 +958,7 @@ clearlooks_draw_menubar2 (cairo_t *cr,
 	cairo_stroke          (cr);
 }
 
-void
+static void
 clearlooks_draw_menubar1 (cairo_t *cr,
                           const ClearlooksColors *colors,
                           const WidgetParameters *params,
@@ -980,7 +976,7 @@ clearlooks_draw_menubar1 (cairo_t *cr,
 }
 
 
-static menubar_draw_proto menubar_draw[3] = { clearlooks_draw_menubar0, 
+static menubar_draw_proto clearlooks_menubar_draw[3] = { clearlooks_draw_menubar0, 
                                               clearlooks_draw_menubar1,
                                               clearlooks_draw_menubar2 };
 
@@ -996,7 +992,7 @@ clearlooks_draw_menubar (cairo_t *cr,
 	if (menubar->style < 0 || menubar->style > 3)
 		return;
 
-	menubar_draw[menubar->style](cr, colors, params, menubar,
+	clearlooks_menubar_draw[menubar->style](cr, colors, params, menubar,
 	                             x, y, width, height);
 }
 
@@ -1406,7 +1402,7 @@ clearlooks_draw_menuitem (cairo_t *cr,
 	CairoColor *border = (CairoColor*)&colors->spot[2];
 	cairo_pattern_t *pattern;
 	
-	shade (fill, &fill_shade, 0.85);
+	ge_shade_color (fill, 0.85, &fill_shade);
 	
 	cairo_translate      (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
@@ -1437,7 +1433,7 @@ clearlooks_draw_scrollbar_trough (cairo_t *cr,
 	CairoColor       bg_shade;
 	cairo_pattern_t *pattern;
 	
-	shade (bg, &bg_shade, 0.95);
+	ge_shade_color (bg, 0.95, &bg_shade);
 	
 	cairo_set_line_width (cr, 1);
 	//cairo_translate (cr, x, y);
@@ -1445,7 +1441,7 @@ clearlooks_draw_scrollbar_trough (cairo_t *cr,
 	if (scrollbar->horizontal)
 	{
 		int tmp = height;
-		rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
+		clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
 		height = width;
 		width = tmp;
 	}
@@ -1504,8 +1500,8 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CL_CORNER_BOTTOMLEFT | CL_CORNER_BOTTOMRIGHT;
 	}
 	
-	shade (bg, &bg_shade1, 0.95);
-	shade (bg, &bg_shade2, 1.02);
+	ge_shade_color (bg, 0.95, &bg_shade1);
+	ge_shade_color (bg, 1.02, &bg_shade2);
 	
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1);
@@ -1580,20 +1576,20 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		else
 		{
 			int tmp = height;
-			rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
+			clearlooks_rotate_mirror_translate (cr, M_PI/2, x, y, FALSE, FALSE);
 			height = width;
 			width = tmp;
 		}
 	
 		if (widget->prelight)
-			shade (&fill, &fill, 1.1);
+			ge_shade_color (&fill, 1.1, &fill);
 			
 		cairo_set_line_width (cr, 1);
 		
-		shade (&fill, &hilight, 1.2);
-		shade (&fill, &shade1, 1.1);
-		shade (&fill, &shade2, 1.05);
-		shade (&fill, &shade3, 0.98);
+		ge_shade_color (&fill, 1.2, &hilight);
+		ge_shade_color (&fill, 1.1, &shade1);
+		ge_shade_color (&fill, 1.05, &shade2);
+		ge_shade_color (&fill, 0.98, &shade3);
 		
 		pattern = cairo_pattern_create_linear (2, 2, 2, height-4);
 		cairo_pattern_add_color_stop_rgb (pattern, 0,   shade1.r, shade1.g, shade1.b);
@@ -1687,7 +1683,7 @@ clearlooks_draw_handle (cairo_t *cr,
 		num_bars    = 12;
 		bar_spacing = 2;
 	}
-	else if (handle->type == CL_HANDLE_SPLITTER)
+	else /* if (handle->type == CL_HANDLE_SPLITTER) */
 	{
 		num_bars    = 20;
 		bar_spacing = 2;
@@ -1698,7 +1694,7 @@ clearlooks_draw_handle (cairo_t *cr,
 	if (handle->horizontal)
 	{
 		int tmp = height;
-		rotate_mirror_translate (cr, M_PI/2,
+		clearlooks_rotate_mirror_translate (cr, M_PI/2,
 		                         x + 0.5 + width/2 - bar_height/2,
 		                         y + height/2 - bar_width/2,
 		                         FALSE, FALSE);
@@ -1791,7 +1787,7 @@ _clearlooks_draw_arrow (cairo_t *cr, CairoColor *color,
 	
 	if (type == CL_ARROW_NORMAL)
 	{		
-		rotate_mirror_translate (cr, rotate, x, y, FALSE, FALSE);		
+		clearlooks_rotate_mirror_translate (cr, rotate, x, y, FALSE, FALSE);		
 		clearlooks_draw_normal_arrow (cr, color, 0, 0, width, height);
 	}
 	else if (type == CL_ARROW_COMBO)
